@@ -58,7 +58,7 @@ int mworkers = 1;   /* Peak started concurrent worker threads */
 int aworkers = 0;   /* Currently active probing worker threads */
 int nworkers = 0;   /* Max concurrent worker threads */
 
-int timeout = 1000; /* ms */
+int timeout = 2000; /* ms */
 int pr_sym  = 0;
 int line_f  = 0;
 int use_shutdown = 0;
@@ -772,7 +772,8 @@ get_service(char *str,
 	    int *pp)
 {
     struct servent *sep;
-
+    char c;
+    
 
     sep = getservbyname(str, "tcp");
     if (sep)
@@ -781,7 +782,7 @@ get_service(char *str,
 	return 1;
     }
 
-    if (sscanf(str, "%u", pp) != 1)
+    if (sscanf(str, "%u%c", pp, &c) != 1)
 	return -1;
 
     if (*pp < 1 || *pp > 65535)
@@ -816,7 +817,6 @@ f_worker(void *arg)
 	}
 
 	host = strtok_r(buf, " \t\n\r", &tokp);
-	serv = strtok_r(NULL, " \t\n\r", &tokp);
 	
 	if (host == NULL || host[0] == '#')
 	    continue;
@@ -828,6 +828,8 @@ f_worker(void *arg)
 	    continue;
 	}
 	
+	serv = strtok_r(NULL, " \t\n\r", &tokp);
+	
 	if (serv == NULL)
 	{
 	    if (first_port == 0)
@@ -1213,8 +1215,21 @@ main(int argc,
     if (i == argc || i+1 == argc)
     {
 	if (i + 1 == argc)
-	    get_service(argv[i], &first_port);
-			  
+	    if (get_service(argv[i], &first_port) != 1)
+	    {
+		fprintf(stderr, "%s: Invalid port/service: %s\n",
+			argv[0], argv[i]);
+		exit(1);
+	    }
+
+	if (verbose || isatty(0))
+	{
+	    if (!isatty(0))
+		fprintf(stderr, "[Reading host/address data from stdin]\n");
+	    else
+		fprintf(stderr, "[Waiting for host/address data on stdin]\n");
+	}
+	
 	f_worker(NULL);
 	pthread_exit(NULL);
 	
